==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/sl-SI/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'a_user_canceled' => 'Uporabnik je preklical zahtevo za sredstev na spletnem mestu',
    'a_user_requested' => 'Uporabnik je zahteval sredstev na spletnem mestu',
    'accessory_name' => 'Ime Dodatka:',
    'additional_notes' => 'Dodatne opombe:',
    'admin_has_created' => 'Skrbnik vam je ustvaril račun na :web spletni strani.',
    'asset' => 'Sredstvo:',
    'asset_name' => 'Ime sredstva:',
    'asset_requested' => 'Sredstev zahtevano',
    'asset_tag' => 'Oznaka sredstva',
    'assigned_to' => 'Dodeljena',
    'best_regards' => 'Lep pozdrav,',
    'canceled' => 'Preklicana:',
    'checkin_date' => 'Datum sprejema:',
    'checkout_date' => 'Datum izdaje:',
    'click_to_confirm' => 'Prosimo, kliknite na naslednjo povezavo, da potrdite svoj :spletni račun:',
    'click_on_the_link_accessory' => 'Prosimo, kliknite povezavo na dnu, da potrdite, da ste prejeli dodatno opremo.',
    'click_on_the_link_asset' => 'Prosimo, kliknite na povezavo na dnu, da potrdite, da ste prejeli opremo.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Trenutna količina',
    'Days' => 'Dnevi',
    'days' => 'Dnevi',
    'expecting_checkin_date' => 'Predviden datum dobave:',
    'expires' => 'Poteče',
    'Expiring_Assets_Report' => 'Poročilo o izteku sredstev.',
    'Expiring_Licenses_Report' => 'Poročilo o izteku licenc.',
    'hello' => 'Pozdravljeni',
    'hi' => 'Zdravo',
    'i_have_read' => 'Sem prebral oz. prebrala in se strinjam s pogoji uporabe. Potrjujem prejetje opreme.',
    'item' => 'Element:',
    'Item_Request_Canceled' => 'Zahteva je bila preklicana',
    'Item_Requested' => 'Zahtevana postavka',
    'link_to_update_password' => 'Prosimo, kliknite na to povezavo, da posodobite svoje: spletno geslo:',
    'login_first_admin' => 'Prijavite se v svojo novo namestitev Snipe-IT s spodnjimi poverilnicami:',
    'login' => 'Prijava:',
    'Low_Inventory_Report' => 'Poročilo o nizki zalogi',
    'inventory_report' => 'Inventory Report',
    'min_QTY' => 'Min kol',
    'name' => 'Ime',
    'new_item_checked' => 'Pod vašim imenom je bil izdan nov element, spodaj so podrobnosti.',
    'password' => 'Geslo:',
    'password_reset' => 'Ponastavitev gesla',

    'read_the_terms' => 'Prosimo, preberite pogoje uporabe spodaj.',
    'read_the_terms_and_click' => 'Preberite spodnje pogoje uporabe in kliknite spodnjo povezavo, da potrdite, da ste prebrali in se strinjali s pogoji uporabe. S tem potrdite, da ste prejeli sredstva.',
    'requested' => 'Zahtevano:',
    'reset_link' => 'Povezava za ponastavitev gesla',
    'reset_password' => 'Kliknite tukaj, če želite ponastaviti geslo:',
    'serial' => 'Serijska številka',
    'supplier' => 'Dobavitelj',
    'tag' => 'Oznaka',
    'test_email' => 'Testna e-pošta od Snipe-IT',
    'test_mail_text' => 'To je testna e-pošta sistema Snipe-IT Asset Management. Če ste prejeli to e-pošto, potem pošta dela. :)',
    'the_following_item' => 'Naslednji element je bil sprejet: ',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Če želite ponastaviti svoje: spletno geslo, izpolnite ta obrazec:',
    'type' => 'Tip',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Uporabnik',
    'username' => 'Uporabniško ime',
    'welcome' => 'Dobrodošli: ime',
    'welcome_to' => 'Dobrodošli na :web!',
    'your_credentials' => 'Vaše poverilnice Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
    'rights_reserved' => 'All rights reserved.',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/sl-SI/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Dnevi',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Poročilo o izteku sredstev.',
    'Expiring_Licenses_Report' => 'Poročilo o izteku licenc.',
    'Item_Request_Canceled' => 'Zahteva je bila preklicana',
    'Item_Requested' => 'Zahtevana postavka',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Poročilo o nizki zalogi',
    'a_user_canceled' => 'Uporabnik je preklical zahtevo za sredstev na spletnem mestu',
    'a_user_requested' => 'Uporabnik je zahteval sredstev na spletnem mestu',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Ime Dodatka',
    'additional_notes' => 'Dodatne opombe',
    'admin_has_created' => 'Skrbnik vam je ustvaril račun na :web spletni strani.',
    'asset' => 'Sredstev',
    'asset_name' => 'Ime sredstva',
    'asset_requested' => 'Sredstev zahtevano',
    'asset_tag' => 'Oznaka sredstva',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Dodeljena',
    'best_regards' => 'Lep pozdrav,',
    'canceled' => 'Preklicana',
    'checkin_date' => 'Datum sprejema',
    'checkout_date' => 'Datum Izdaje',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Prosimo, kliknite povezavo na dnu, da potrdite, da ste prejeli dodatno opremo.',
    'click_on_the_link_asset' => 'Prosimo, kliknite na povezavo na dnu, da potrdite, da ste prejeli opremo.',
    'click_to_confirm' => 'Prosimo, kliknite na naslednjo povezavo, da potrdite svoj :spletni račun:',
    'current_QTY' => 'Trenutna količina',
    'days' => 'Dnevi',
    'expecting_checkin_date' => 'Predviden datum dobave',
    'expires' => 'Poteče',
    'hello' => 'Pozdravljeni',
    'hi' => 'Zdravo',
    'i_have_read' => 'Sem prebral oz. prebrala in se strinjam s pogoji uporabe. Potrjujem prejetje opreme.',
    'inventory_report' => 'Poročilo o inventarju',
    'item' => 'Element',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'link_to_update_password' => 'Prosimo, kliknite na to povezavo, da posodobite svoje: spletno geslo:',
    'login' => 'Prijava:',
    'login_first_admin' => 'Prijavite se v svojo novo namestitev Snipe-IT s spodnjimi poverilnicami:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'Min kol',
    'name' => 'Ime',
    'new_item_checked' => 'Pod vašim imenom je bil izdan nov element, spodaj so podrobnosti.',
    'notes' => 'Opombe',
    'password' => 'Geslo',
    'password_reset' => 'Ponastavitev gesla',
    'read_the_terms' => 'Prosimo, preberite pogoje uporabe spodaj.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Zahtevano',
    'reset_link' => 'Povezava za ponastavitev gesla',
    'reset_password' => 'Kliknite tukaj, če želite ponastaviti geslo:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Serijska številka',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Dobavitelj',
    'tag' => 'Oznaka',
    'test_email' => 'Testna e-pošta od Snipe-IT',
    'test_mail_text' => 'To je testna e-pošta sistema Snipe-IT Asset Management. Če ste prejeli to e-pošto, potem pošta dela. :)',
    'the_following_item' => 'Naslednji element je bil sprejet: ',
    'to_reset' => 'Če želite ponastaviti svoje: spletno geslo, izpolnite ta obrazec:',
    'type' => 'Tip',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Uporabnik',
    'username' => 'Uporabniško ime',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Dobrodošli: ime',
    'welcome_to' => 'Dobrodošli na :web!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Vaše poverilnice Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
